\name{ex2.sim}
\alias{ex2.sim}
\docType{data}
\title{Bivpois Example 2 Dataset: Simulated Data}
\description{
The data has one pair (x,y) of diagonal inflated bivariate Poisson variables and five variables (z1,,z5) generated from  N(0, 0.12) distribution. Hence
Xi, Yi ~ DIBP( lambda_1i, lambda_2i, lambda_3i  , p=0.30,  Poisson(2) ) 
loglambda_1i = 1.8 + 2 Z1i + 3 Z3i
loglambda_2i = 0.7  Z1i  3 Z3i + 3 Z5i
loglambda_3i = 1.7 + Z1i  2 Z2i + 2 Z3i  2 Z4i
}
\usage{data(ex2.sim)}
\format{
  A data frame with 100 observations on the following 7 variables.
  \describe{
    \item{x,y}{Simulated Bivariate Poisson Variables used as response}
    \item{z1,z2,z3,z4,z5}{Simulated N(0,0.01) explanatory variables}
  }
}
\details{
	This data is used as example one in Karlis and Ntzoufras (2004). 
}
\source{
Karlis, D. and Ntzoufras, I. (2004). Bivariate Poisson and Diagonal Inflated Bivariate Poisson Regression Models in S. (submitted). Technical Report, Department of Statistics, Athens University of Economics and Business, Athens, Greece.
}

\references{Karlis, D. and Ntzoufras, I. (2003). Analysis of Sports Data Using Bivariate Poisson Models. Journal of the Royal Statistical Society, D, (Statistician), 52, 381  393. 
}
\examples{
library(bivpois) # load bivpois library
data(ex2.sim)    # load ex2.sim data from bivpois library
#
# formula for lambda1 and lamba2
form1 <- y1y2~noncommon + z1:noncommon + z3 + I(l2*z5)
# formula for lambda3 
form2 <- y3~z1+z2+z3+z4
#
# Model  1: BivPois
ex2.m1 <-lm.bp  ( 'x', 'y', form1, form2, data=ex2.sim)
# Model  2: Zero Inflated BivPois 
ex2.m2 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=0 )
# Model  3: Diagonal Inflated BivPois with DISCRETE(1) diagonal inflation distribution
ex2.m3 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=1 )
# Model  4: Diagonal Inflated BivPois with DISCRETE(2) diagonal inflation distribution
ex2.m4 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=2 )
# Model  5: Diagonal Inflated BivPois with DISCRETE(3) diagonal inflation distribution
ex2.m5 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=3 )
# Model  6: Diagonal Inflated BivPois with DISCRETE(4) diagonal inflation distribution
ex2.m6 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=4 )
# Model  7: Diagonal Inflated BivPois with DISCRETE(5) diagonal inflation distribution
ex2.m7 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=5 )
# Model  8: Diagonal Inflated BivPois with DISCRETE(6) diagonal inflation distribution
ex2.m8 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='discrete', jmax=6 )
# Model  9: Diagonal Inflated BivPois with POISSON diagonal inflation distribution
ex2.m9 <-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='poisson' )
# Model 10: Diagonal Inflated BivPois with GEOMETRIC diagonal inflation distribution
ex2.m10<-lm.dibp( 'x', 'y', form1, form2, data=ex2.sim, distribution='geometric' )
#
# printing parameters of model 7
ex2.m7$beta1
ex2.m7$beta2
ex2.m7$beta3
ex2.m7$p
ex2.m7$theta
#
# printing parameters of model 9
ex2.m9$beta1
ex2.m9$beta2
ex2.m9$beta3
ex2.m9$p
ex2.m9$theta
}
\keyword{datasets}
\keyword{models}
\keyword{regression}
